# Changelog

All notable changes to this project will be documented in this file.

## [0.1] - 2024-07-06

### Changed

- `phantomhv-ctl` usage is now based on subcommands

### Added

- PyPi packaging and documentation on Github pages
- `phantomhv-webui` to complement the existing CLI tool
- `PhantomHVStateBuffer` for buffered high-level access
